@@ -106,6 +106,7 @@ curl_option_types <- function(opts = curl::curl_options()) {
 #' @export
 print.opts_list <- function(x, ...) {
   cat(paste0(format(names(x)), ": ", x, collapse = "\n"), "\n", sep = "")
+  invisible(x)
 }
 
 translate_curl <- function(x) {
@@ -129,13 +130,18 @@ curl_docs <- function(x) {
   BROWSE(url)
 }
 
+cache <- new.env(parent = emptyenv())
+cache$default_ua <- NULL
+
 default_ua <- function() {
-  versions <- c(
-    libcurl = curl::curl_version()$version,
-    `r-curl` = as.character(packageVersion("curl")),
-    httr = as.character(packageVersion("httr"))
-  )
-  paste0(names(versions), "/", versions, collapse = " ")
+  if (is.null(cache$default_ua)) {
+    versions <- c(
+      libcurl = curl::curl_version()$version,
+      `r-curl` = as.character(utils::packageVersion("curl")),
+      httr = as.character(utils::packageVersion("httr")))
+    cache$default_ua <- paste0(names(versions), "/", versions, collapse = " ")
+  }
+  cache$default_ua
 }
 
 #' Set (and reset) global httr configuration.
