@@ -132,7 +132,7 @@ Token <- R6::R6Class("Token", list(
 #' @param as_header If \code{TRUE}, the default, sends oauth in header.
 #'   If \code{FALSE}, adds as parameter to url.
 #' @param cache A logical value or a string. \code{TRUE} means to cache
-#'   using the default cache file \code{.oauth-httr}, \code{FALSE} means
+#'   using the default cache file \code{.httr-oauth}, \code{FALSE} means
 #'   don't cache, and \code{NA} means to guess using some sensible heuristics.
 #'   A string mean use the specified path as the cache file.
 #' @return A \code{Token1.0} reference class (RC) object.
@@ -220,7 +220,7 @@ Token2.0 <- R6::R6Class("Token2.0", inherit = Token, list(
   },
   refresh = function() {
     cred <- refresh_oauth2.0(self$endpoint, self$app,
-        self$credentials, self$params$user_params)
+        self$credentials, self$params$user_params, self$params$use_basic_auth)
     if (is.null(cred)) {
       remove_cached_token(self)
     } else {
