@@ -45,7 +45,10 @@ parse_url <- function(url) {
   scheme <- pull_off("^([[:alpha:]+.-]+):")
   netloc <- pull_off("^//([^/?]*)/?")
 
-  if (!is.null(netloc)) {
+  if (identical(netloc, "")) { # corresponds to ///
+    url <- paste0("/", url)
+    port <- username <- password <- hostname <- NULL
+  } else if (!is.null(netloc)) {
 
     pieces <- strsplit(netloc, "@")[[1]]
     if (length(pieces) == 1) {
@@ -88,6 +91,7 @@ parse_url <- function(url) {
 is.url <- function(x) inherits(x, "url")
 print.url <- function(x, ...) {
   cat("Url: ", build_url(x), "\n", sep = "")
+  invisible(x)
 }
 "[.url" <- function(x, ...) {
   structure(NextMethod(), class = "url")
@@ -107,7 +111,7 @@ build_url <- function(url) {
     port <- NULL
   }
 
-  path <- url$path
+  path <- paste(gsub("^/", "", url$path), collapse = "/")
 
   if (!is.null(url$params)) {
     params <- paste0(";", url$params)
@@ -116,11 +120,7 @@ build_url <- function(url) {
   }
 
   if (is.list(url$query)) {
-    url$query <- compact(url$query)
-    names <- curl::curl_escape(names(url$query))
-    values <- curl::curl_escape(as.character(url$query))
-
-    query <- paste0(names, "=", values, collapse = "&")
+    query <- compose_query(url$query)
   } else {
     query <- url$query
   }
@@ -142,7 +142,7 @@ build_url <- function(url) {
 
 #' Modify a url.
 #'
-#' Modify a url by first parsing and it then replacing components with
+#' Modify a url by first parsing it and then replacing components with
 #' the non-NULL arguments of this function.
 #'
 #' @export
@@ -159,8 +159,7 @@ modify_url <- function(url, scheme = NULL, hostname = NULL, port = NULL,
     query = query, params = params, fragment = fragment,
     username = username, password = password))
 
-  build_url(modifyList(old, new))
+  build_url(utils::modifyList(old, new))
 }
 
-
 compact <- function(x) Filter(Negate(is.null), x)
